%global sname   postgis
%global postgissuffix 21
%global postgismajorversion 2.1
%{!?utils:%define utils 1}

Summary:        Geographic Information Systems Extensions to PostgreSQL
Name:           %{sname}%{postgissuffix}
Version:        2.1.0
Release:        3%{?dist}
License:        GPLv2+
Group:          Applications/Databases
Source0:        http://download.osgeo.org/%{sname}/source/%{sname}-%{version}.tar.gz
Source2:        http://www.postgis.org/download/%{sname}-%{version}.pdf
Source4:        filter-requires-perl-Pg.sh

URL:            http://postgis.refractions.net/
BuildRoot:      %{_tmppath}/%{name}-%{version}-%{release}-root-%(%{__id_u} -n)

BuildRequires:  proj-devel, geos-devel >= 3.3.2, proj-devel, flex, json-c-devel
BuildRequires:  postgresql-devel >= 9.2, gdal-devel
BuildRequires:  libxml2-devel

Requires:       postgresql >= 9.2, geos, proj, hdf5, json-c

Patch0:         postgis21-spatial_ref_sys-krovak.patch

%description
PostGIS adds support for geographic objects to the PostgreSQL object-relational
database. In effect, PostGIS "spatially enables" the PostgreSQL server,
allowing it to be used as a backend spatial database for geographic information
systems (GIS), much like ESRI's SDE or Oracle's Spatial extension. PostGIS
follows the OpenGIS "Simple Features Specification for SQL" and has been
certified as compliant with the "Types and Functions" profile.

%package client
Summary:	Client programs for importing and exporting data to/from PostGIS 
Group:		Applications/Databases
Requires:	postgresql-libs >= 9.2

%description client
The postgis-client package includes shp2pgsql, shp2pgsql.gui and pgsql2shp, in order to allow the import of Shapefiles to PostGIS and the export in Shapefile format.

%package devel
Summary:        Development headers and libraries for PostGIS
Group:          Development/Libraries
Requires:       %{name}%{?_isa} = %{version}-%{release}

%description devel
The postgis-devel package contains the header files and libraries
needed to compile C or C++ applications which will directly interact
with PostGIS.

%package docs
Summary:        Extra documentation for PostGIS
Group:          Applications/Databases

%description docs
The postgis-docs package includes PDF documentation of PostGIS.

%if %utils
%package utils
Summary:        The utils for PostGIS
Group:          Applications/Databases
Requires:       %{name} = %{version}-%{release}, perl-DBD-Pg

%description utils
The postgis-utils package provides the utilities for PostGIS.
%endif

%define __perl_requires %{SOURCE4}

%prep
%setup -q -n %{sname}-%{version}
%patch0 -p1 -b .krovak

# Copy .pdf file to top directory before installing.
cp -p %{SOURCE2} .

%build
%configure --with-pgconfig=%{_bindir}/pg_config --with-raster --disable-rpath --with-gui
make %{?_smp_mflags} LPATH=`pg_config --pkglibdir` shlib="%{sname}.so"

%if %utils
 make -C utils
%endif

%install
rm -rf %{buildroot}
make install DESTDIR=%{buildroot}

for file in %{buildroot}%{_bindir}/* ; do
   mv ${file} ${file}%{postgissuffix}
done

%if %utils
install -d %{buildroot}%{_datadir}/%{sname}-%{version}
install -m 644 utils/*.pl %{buildroot}%{_datadir}/%{sname}-%{version}
%endif

pushd %{buildroot}%{_datadir}/pgsql/extension
mv %{sname}.control %{name}.control
for file in $(/bin/ls %{sname}-*-%{version}*.sql) ; do 
   mv $file ${file//%{sname}--/%{name}--} ; 
done

mv %{sname}_topology.control %{name}_topology.control
for file in $(/bin/ls %{sname}_topology-*-%{version}*.sql) ; do 
   mv $file ${file//%{sname}_topology--/%{name}_topology--} ; 
done

mv %{sname}_tiger_geocoder.control %{name}_tiger_geocoder.control
for file in $(/bin/ls %{sname}_tiger_geocoder-*-%{version}*.sql) ; do 
   mv $file ${file//%{sname}_tiger_geocoder--/%{name}_tiger_geocoder--} ; 
done
popd

pushd %{buildroot}%{_libdir}
mv liblwgeom.so liblwgeom-%{postgismajorversion}.so
popd

%clean
rm -rf %{buildroot}

%files
%defattr(-,root,root)
%doc COPYING CREDITS NEWS TODO README.%{sname} doc/%{sname}.xml doc/ZMSgeoms.txt
%attr(755,root,root) %{_libdir}/pgsql/%{sname}-%{postgismajorversion}.so
%attr(755,root,root) %{_libdir}/pgsql/rtpostgis-%{postgismajorversion}.so
%{_libdir}/liblwgeom*.so
%{_datadir}/pgsql/contrib/%{sname}-%{postgismajorversion}/*.sql
%{_datadir}/pgsql/contrib/%{sname}-%{postgismajorversion}/postgis_restore.pl
%{_datadir}/pgsql/extension/%{name}-*.sql
%{_datadir}/pgsql/extension/%{name}.control
%{_datadir}/pgsql/extension/%{name}_topology-*.sql
%{_datadir}/pgsql/extension/%{name}_topology.control
%{_datadir}/pgsql/extension/%{name}_tiger_geocoder-*.sql
%{_datadir}/pgsql/extension/%{name}_tiger_geocoder.control

%files client
%defattr(-,root,root)
%doc loader/README.* 
%attr(755,root,root) %{_bindir}/*

%files devel
%defattr(644,root,root)
%{_includedir}/liblwgeom.h
%{_libdir}/liblwgeom.a
%{_libdir}/liblwgeom.la

%if %utils
%files utils
%defattr(-,root,root)
%doc utils/README
%dir %{_datadir}/%{sname}-%{version}
%attr(755,root,root) %{_datadir}/%{sname}-%{version}/*.pl
%endif

%files docs
%defattr(-,root,root)
%doc %{sname}-%{version}.pdf
%doc doc/html

%changelog
* Fri Jul 18 2014 Pavel Lisy <pavel.lisy@tmapy.cz> - 2.1.0-3
- Rebuilt for geos 3.4.2

* Wed Apr 16 2014 Pavel LISY <pavel.lisy@gmail.com> - 2.1.0-2
- Krovak patch

* Mon Oct 21 2013 Pavel LISY <pavel.lisy@gmail.com> - 2.1.0-1
- Update to 2.1.0
- built with postgresql 9.2

* Thu Oct 17 2013 Pavel LISY <pavel.lisy@gmail.com> - 2.0.4-1
- Update to 2.0.4
- built with postgresql 9.2

* Mon Mar 11 2013 Pavel LISY <pavel.lisy@gmail.com> - 2.0.3-1
- Update to 2.0.3
- build with PostgreSQL 8.4

* Mon Dec 10 2012 Devrim GUNDUZ <devrim@gunduz.org> - 2.0.2-1
- Update to 2.0.2.
- Update download URL.
- Add deps for JSON-C support.

* Wed Nov 07 2012 Devrim GUNDUZ <devrim@gunduz.org> - 2.0.1-2
- Add dependency to hdf5, per report from Guillaume Smet.

* Wed Jul 4 2012 Devrim GUNDUZ <devrim@gunduz.org> - 2.0.0-1
- Update to 2.0.1, for changes described at:
  http://postgis.org/news/20120622/

* Tue Apr 3 2012 Devrim GUNDUZ <devrim@gunduz.org> - 2.0.0-1
- Initial packaging with PostGIS 2.0.0.
- Drop java bits from spec file.
